==> com.liferay.faces.bridge.impl-4.0.0-sources.jar: com/liferay/faces/bridge/renderkit/primefaces/internal/FacesContextPrimeFacesHeadImpl.java <==
/**
 * Copyright (c) 2000-2016 Liferay, Inc. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.liferay.faces.bridge.renderkit.primefaces.internal;

import javax.faces.component.UIViewRoot;
import javax.faces.context.FacesContext;
import javax.faces.context.FacesContextWrapper;


/**
 * @author  Neil Griffin
 */
public class FacesContextPrimeFacesHeadImpl extends FacesContextWrapper {

	// Private Data Members
	private FacesContext wrappedFacesContext;
	private UIViewRoot viewRoot;

	public FacesContextPrimeFacesHeadImpl(FacesContext facesContext) {
		this.wrappedFacesContext = facesContext;
	}

	@Override
	public UIViewRoot getViewRoot() {

		if (viewRoot == null) {
			return super.getViewRoot();
		}
		else {
			return viewRoot;
		}
	}

	@Override
	public FacesContext getWrapped() {
		return wrappedFacesContext;
	}

	@Override
	public void setViewRoot(UIViewRoot viewRoot) {

		// Override the setViewRoot method in order to prevent the JSF implementation from clearing all the view
		// scoped managed beans.
		this.viewRoot = viewRoot;
	}
}

==> com.liferay.faces.bridge.impl-4.1.0-sources.jar: com/liferay/faces/bridge/renderkit/primefaces/internal/FacesContextPrimeFacesHeadImpl.java <==
/**
 * Copyright (c) 2000-2017 Liferay, Inc. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.liferay.faces.bridge.renderkit.primefaces.internal;

import javax.faces.application.Application;
import javax.faces.component.UIViewRoot;
import javax.faces.context.FacesContext;
import javax.faces.context.FacesContextWrapper;


/**
 * @author  Neil Griffin
 */
public class FacesContextPrimeFacesHeadImpl extends FacesContextWrapper {

	// Private Data Members
	private FacesContext wrappedFacesContext;
	private UIViewRoot viewRoot;

	public FacesContextPrimeFacesHeadImpl(FacesContext facesContext) {
		this.wrappedFacesContext = facesContext;
	}

	@Override
	public Application getApplication() {

		Application application = super.getApplication();

		return new ApplicationPrimeFacesHeadImpl(application);
	}

	@Override
	public UIViewRoot getViewRoot() {

		if (viewRoot == null) {
			return super.getViewRoot();
		}
		else {
			return viewRoot;
		}
	}

	@Override
	public FacesContext getWrapped() {
		return wrappedFacesContext;
	}

	@Override
	public void setViewRoot(UIViewRoot viewRoot) {

		// Override the setViewRoot method in order to prevent the JSF implementation from clearing all the view
		// scoped managed beans.
		this.viewRoot = viewRoot;
	}
}
